/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.phonetic;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.impl.grammar.exceptions.KemetAPIException;
import org.kemet.impl.grammar.integration.HieroglyphManager;
import org.kemet.tests.TestRoot;

/**
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>phonetic tests : analyze phonetic read.</b>
 * </p>
 * 
 * @since 0.2.3
 * 
 */
public class TestsToPhonetic extends TestRoot {
	static final Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>initialize the parameters before to execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	public void init() {
		// nothing
	}

	/**
	 * <p>
	 * <b>get the phonetic read 1.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test1() {
		// initialize the data tests
		sequence = "U21";
		result = new String[] { "sétèp" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 2.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test2() {
		// initialize the data tests
		sequence = "D46D58V28";
		result = new String[] { "débéh" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 3.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test3() {
		// initialize the data tests
		sequence = "D58N35D21";
		result = new String[] { "bénèr" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 4.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test4() {
		// initialize the data tests
		sequence = "F21";
		result = new String[] { "sédjèm" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 5.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test5() {
		// initialize the data tests
		sequence = "D58M17N35";
		result = new String[] { "bine" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 6.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test6() {
		// initialize the data tests
		sequence = "G43N37D58";
		result = new String[] { "ouchèb" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 7.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test7() {
		// initialize the data tests
		sequence = "M2D36";
		result = new String[] { "héna" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 8.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test8() {
		// initialize the data tests
		sequence = "G17S3N35";
		result = new String[] { "ménèn" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read (with feminine grammatical kind).</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test9() {
		// initialize the data tests
		sequence = "V4X1M16X1";
		result = new String[] { "ouathat" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo, TO_READ);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}

	/**
	 * <p>
	 * <b>get the phonetic read 10.</b>
	 * </p>
	 * 
	 * @since 0.2.3
	 */
	@Test
	public void test10() {
		// initialize the data tests
		sequence = "M3";
		result = new String[] { "khèt" };

		hieroglyph = new HieroglyphManager(sequence, gm, phInfo,
				TO_READ_COMPLETE);
		String[] res;

		try {
			res = hieroglyph.analyze();
			assertEquals(res.length, result.length);

			if (res.length == result.length) {
				for (int i = 0; i < res.length; i++) {
					log.info("res(i) = " + res[i]);
					assertEquals(res[i], result[i]);
				}
			}
		} catch (KemetAPIException e) {
			assertTrue(false);
		}
	}
}
